@@ -1,23 +1,10 @@
 /*
     This file is part of the KDE libraries
 
-    Copyright (C) 1999 Waldo Bastian (bastian@kde.org)
-    Copyright (C) 2002 Michael Matz (matz@kde.org)
+    SPDX-FileCopyrightText: 1999 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2002 Michael Matz <matz@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 /* Fast zone memory allocator with deallocation support, for use as obstack
@@ -29,6 +16,8 @@
 
 #include "kzoneallocator_p.h"
 
+#include <kcompletion_debug.h>
+
 #include <QList>
 
 #include <stdio.h>
@@ -36,18 +25,23 @@
 class KZoneAllocator::MemBlock
 {
 public:
-    MemBlock(size_t s) : size(s), ref(0), older(0), newer(0)
+    MemBlock(size_t s)
+        : size(s)
+        , ref(0)
+        , older(nullptr)
+        , newer(nullptr)
     {
         begin = new char[s];
     }
     ~MemBlock()
     {
-        delete [] begin;
+        delete[] begin;
     }
+    MemBlock(const MemBlock &) = delete;
+    MemBlock &operator=(const MemBlock &) = delete;
     bool is_in(void *ptr) const
     {
-        return !(begin > (char *)ptr
-                 || (begin + size) <= (char *)ptr);
+        return !(begin > (char *)ptr || (begin + size) <= (char *)ptr);
     }
     size_t size;
     unsigned int ref;
@@ -60,9 +54,14 @@ class KZoneAllocator::Private
 {
 public:
     Private()
-        : currentBlock(0), blockSize(1),
-          blockOffset(0), log2(0), num_blocks(0),
-          hashList(0), hashSize(0), hashDirty(true)
+        : currentBlock(nullptr)
+        , blockSize(1)
+        , blockOffset(0)
+        , log2(0)
+        , num_blocks(0)
+        , hashList(nullptr)
+        , hashSize(0)
+        , hashDirty(true)
     {
     }
 
@@ -106,8 +105,8 @@ KZoneAllocator::~KZoneAllocator()
         for (unsigned int i = 0; i < d->hashSize; i++) {
             delete d->hashList[i];
         }
-        delete [] d->hashList;
-        d->hashList = 0;
+        delete[] d->hashList;
+        d->hashList = nullptr;
     }
     MemBlock *next;
     for (; d->currentBlock; d->currentBlock = next) {
@@ -118,7 +117,7 @@ KZoneAllocator::~KZoneAllocator()
 #ifndef NDEBUG // as this is called quite late in the app, we don't care
     // to use qDebug
     if (count > 1) {
-        fprintf(stderr, "zone still contained %d blocks", count);
+        fprintf(stderr, "zone still contained %u blocks", count);
     }
 #endif
     delete d;
@@ -146,7 +145,7 @@ void KZoneAllocator::insertHash(MemBlock *b)
 */
 void KZoneAllocator::addBlock(MemBlock *b)
 {
-    b->newer = 0;
+    b->newer = nullptr;
     b->older = d->currentBlock;
     if (d->currentBlock) {
         b->older->newer = b;
@@ -173,8 +172,8 @@ void KZoneAllocator::initHash()
         for (unsigned int i = 0; i < d->hashSize; i++) {
             delete d->hashList[i];
         }
-        delete [] d->hashList;
-        d->hashList = 0;
+        delete[] d->hashList;
+        d->hashList = nullptr;
     }
     d->hashSize = 1;
     while (d->hashSize < d->num_blocks) {
@@ -228,28 +227,27 @@ void KZoneAllocator::delBlock(MemBlock *b)
         b->newer->older = b->older;
     }
     if (b == d->currentBlock) {
-        d->currentBlock = 0;
+        d->currentBlock = nullptr;
         d->blockOffset = d->blockSize;
     }
     delete b;
     d->num_blocks--;
 }
 
-void *
-KZoneAllocator::allocate(size_t _size)
+void *KZoneAllocator::allocate(size_t _size)
 {
     // Use the size of (void *) as alignment
     const size_t alignment = sizeof(void *) - 1;
     _size = (_size + alignment) & ~alignment;
 
-    if ((unsigned long) _size + d->blockOffset > d->blockSize) {
+    if ((unsigned long)_size + d->blockOffset > d->blockSize) {
         if (_size > d->blockSize) {
-            qDebug("KZoneAllocator: allocating more than %zu bytes", (size_t)d->blockSize);
-            return 0;
+            qCDebug(KCOMPLETION_LOG, "KZoneAllocator: allocating more than %zu bytes", (size_t)d->blockSize);
+            return nullptr;
         }
         addBlock(new MemBlock(d->blockSize));
         d->blockOffset = 0;
-        //qDebug ("Allocating block #%d (%x)\n", d->num_blocks, d->currentBlock->begin);
+        // qDebug ("Allocating block #%d (%x)\n", d->num_blocks, d->currentBlock->begin);
     }
     void *result = (void *)(d->currentBlock->begin + d->blockOffset);
     d->currentBlock->ref++;
@@ -257,8 +255,7 @@ KZoneAllocator::allocate(size_t _size)
     return result;
 }
 
-void
-KZoneAllocator::deallocate(void *ptr)
+void KZoneAllocator::deallocate(void *ptr)
 {
     if (d->hashDirty) {
         initHash();
@@ -269,7 +266,7 @@ KZoneAllocator::deallocate(void *ptr)
     if (!list) {
         /* Can happen with certain usage pattern of intermixed free_since()
            and deallocate().  */
-        //qDebug("Uhoh");
+        // qDebug("Uhoh");
         return;
     }
     QList<MemBlock *>::ConstIterator it = list->begin();
@@ -289,11 +286,10 @@ KZoneAllocator::deallocate(void *ptr)
     }
     /* Can happen with certain usage pattern of intermixed free_since()
        and deallocate().  */
-    //qDebug("Uhoh2");
+    // qDebug("Uhoh2");
 }
 
-void
-KZoneAllocator::free_since(void *ptr)
+void KZoneAllocator::free_since(void *ptr)
 {
     /* If we have a d->hashList and it's not yet dirty, see, if we will dirty
        it by removing too many blocks.  This will make the below delBlock()s
